From [Wikipedia](https://en.wikipedia.org/wiki/Cron "wikipedia:Cron"):

***cron** is the time-based job scheduler in Unix-like computer operating systems. cron enables users to schedule jobs (commands or shell scripts) to run periodically at certain times or dates. It is commonly used to automate system maintenance or administration.*

## Contents

*   [1 Installation](#Installation)
*   [2 Configuration](#Configuration)
    *   [2.1 Activation and autostart](#Activation_and_autostart)
    *   [2.2 Handling errors of jobs](#Handling_errors_of_jobs)
        *   [2.2.1 Example with msmtp](#Example_with_msmtp)
        *   [2.2.2 Example with esmtp](#Example_with_esmtp)
        *   [2.2.3 Example with opensmtpd](#Example_with_opensmtpd)
        *   [2.2.4 Long cron job](#Long_cron_job)
*   [3 Crontab format](#Crontab_format)
*   [4 Basic commands](#Basic_commands)
*   [5 Examples](#Examples)
*   [6 Default editor](#Default_editor)
*   [7 run-parts issue](#run-parts_issue)
*   [8 Running X.org server-based applications](#Running_X.org_server-based_applications)
*   [9 Asynchronous job processing](#Asynchronous_job_processing)
    *   [9.1 Cronie](#Cronie)
    *   [9.2 Dcron](#Dcron)
    *   [9.3 Cronwhip](#Cronwhip)
    *   [9.4 Anacron](#Anacron)
    *   [9.5 Fcron](#Fcron)
*   [10 Ensuring exclusivity](#Ensuring_exclusivity)
*   [11 cronie](#cronie_2)
*   [12 Dcron](#Dcron_2)
*   [13 See also](#See_also)

## Installation

There are many cron implementations, but none of them are installed by default as the base system uses [systemd/Timers](/index.php/Systemd/Timers "Systemd/Timers") instead. See the Gentoo's [cron guide](http://www.gentoo.org/doc/en/cron-guide.xml), which offers comparisons.

Packages available:

*   [cronie](https://www.archlinux.org/packages/?name=cronie)
*   [fcron](https://www.archlinux.org/packages/?name=fcron)
*   [bcron](https://aur.archlinux.org/packages/bcron/)
*   [dcron](https://aur.archlinux.org/packages/dcron/)
*   [vixie-cron](https://aur.archlinux.org/packages/vixie-cron/)
*   [scron-git](https://aur.archlinux.org/packages/scron-git/)

## Configuration

### Activation and autostart

After installation, the daemon will not be enabled by default. The installed package likely provides a service, which can be controlled by [systemctl](/index.php/Systemd#Using_units "Systemd"). For example, *cronie* uses `cronie.service`.

Check `/etc/cron.daily/` and similar directories to see which jobs are present. Activating cron service will trigger all of them.

**Note:** *cronie* provides the `0anacron` *hourly* job, which allows for [delayed runs of other jobs](#Asynchronous_job_processing) e.g. if the computer was switched off at the moment of standard execution.

### Handling errors of jobs

cron registers the output from *stdout* and *stderr* and attempts to send it as email to the user's spools via the `sendmail` command. Cronie disables mail output if `/usr/bin/sendmail` is not found. In order for mail to be written to a user's spool, there must be an smtp daemon running on the system, e.g. [opensmtpd](https://www.archlinux.org/packages/?name=opensmtpd). Otherwise, you can install a package that provides the sendmail command, and configure it to send mail to a remote mail exchanger. You can also log the messages by using the `-m` option and writing a custom script.

1.  [Edit](/index.php/Systemd#Editing_provided_units "Systemd") the `cronie.service` unit.
2.  Install [esmtp](https://www.archlinux.org/packages/?name=esmtp), [msmtp](/index.php/Msmtp "Msmtp"), [opensmtpd](https://www.archlinux.org/packages/?name=opensmtpd) or write a custom script.

#### Example with msmtp

Install [msmtp-mta](https://www.archlinux.org/packages/?name=msmtp-mta) which creates a symbolic link from `/usr/bin/sendmail` to `/usr/bin/msmtp`. Restart `cronie` to make sure it detects the new `sendmail` command. You must then provide a way for `msmtp` to convert your username into an email address.

Then either add `MAILTO` line to your crontab, like so:

```
MAILTO=your@email.com

```

**or** create `/etc/msmtprc` and append this line:

```
aliases /etc/aliases

```

and create `/etc/aliases`:

```
your_username: your@email.com
# Optional:
default: your@email.com

```

Then [modify the configuration](/index.php/Systemd#Editing_provided_units "Systemd") of *cronie* daemon by replacing the `ExecStart` command with:

```
ExecStart=/usr/bin/crond -n -m '/usr/bin/msmtp -t'

```

#### Example with esmtp

Install [esmtp](https://www.archlinux.org/packages/?name=esmtp) and [procmail](https://www.archlinux.org/packages/?name=procmail).

After installation configure the routing:

 `/etc/esmtprc` 
```
identity *myself*@myisp.com
       hostname mail.myisp.com:25
       username *"myself"*
       password *"secret"*
       starttls enabled
       default
mda "/usr/bin/procmail -d %T"

```

Procmail needs root privileges to work in delivery mode but it is not an issue if you are running the cronjobs as root anyway.

To test that everything works correctly, create a file `message.txt` with `"test message"` in it.

From the same directory run:

```
$ sendmail *user_name* < message.txt 

```

then:

```
$ cat /var/spool/mail/*user_name*

```

You should now see the test message and the time and date it was sent.

The error output of all jobs will now be redirected to `/var/spool/mail/*user_name*`.

Due to the privileged issue, it is hard to create and send emails to root (e.g. `su -c ""`). You can ask `esmtp` to forward all root's email to an ordinary user with:

 `/etc/esmtprc`  `force_mda="*user-name*"` 
**Note:** If the above test didn't work, you may try creating a local configuration in `~/.esmtprc` with the same content.

Run the following command to make sure it has the correct permission:

```
$ chmod 710 ~/.esmtprc

```
Then repeat the test with `message.txt` exactly as before.

#### Example with opensmtpd

Install [opensmtpd](https://www.archlinux.org/packages/?name=opensmtpd).

Edit `/etc/smtpd/smtpd.conf`. The following configuration allows for local delivery:

```
listen on localhost
accept for local deliver to mbox

```

You can proceed to test it. First [start](/index.php/Start "Start") `smtpd.service`. Then do:

```
$ echo test | sendmail user

```

*user* can check his/her mail in with any [reader](/index.php/Category:Email_clients "Category:Email clients") able to handle mbox format, or just have a look at the file `/var/spool/mail/*user*`. If everything goes as expected, you can [enable](/index.php/Enable "Enable") opensmtpd for future boots.

This approach has the advantage of not sending local cron notifications to a remote server. Not even network connection is needed. On the downside, you need a new daemon running.

**Note:**

*   At the moment of writing the Arch opensmtpd package does not create all needed directories under `/var/spool/smtpd`, but the daemon will warn about that specifying the required ownerships and permissions. Just create them as suggested.
*   Even though the suggested configuration does not accept remote connections, it's a healthy precaution to add an additional layer of security blocking port 25 with [iptables](/index.php/Iptables "Iptables") or similar.

#### Long cron job

Suppose this program is invoked by cron :

```
#!/bin/sh
echo "I had a recoverable error!"
sleep 1h

```

What happens is this:

1.  cron runs the script
2.  as soon as cron sees some output, it runs your MTA, and provides it with the headers. It leaves the pipe open, because the job hasn't finished and there might be more output.
3.  the MTA opens the connection to postfix and leaves that connection open while it waits for the rest of the body.
4.  postfix closes the idle connection after less than an hour and you get an error like this :

```
smtpmsg='421 … Error: timeout exceeded' errormsg='the server did not accept the mail'

```

To solve this problem you can use the command chronic or sponge from [moreutils](https://www.archlinux.org/packages/?name=moreutils). From their respective man page:

	chronic

	chronic runs a command, and arranges for its standard out and standard error to only be displayed if the command fails (exits nonzero or crashes). If the command succeeds, any extraneous output will be hidden.

	sponge

	sponge reads standard input and writes it out to the specified file. Unlike a shell redirect, sponge soaks up all its input before opening the output file… If no output file is specified, sponge outputs to stdout.

Even if it's not said chronic buffer the command output before opening its standard output (like sponge does).

## Crontab format

The basic format for a crontab is:

```
*minute* *hour* *day_of_month* *month* *day_of_week* *command*

```

*   *minute* values can be from 0 to 59.
*   *hour* values can be from 0 to 23.
*   *day_of_month* values can be from 1 to 31.
*   *month* values can be from 1 to 12.
*   *day_of_week* values can be from 0 to 6, with 0 denoting Sunday.

Multiple times may be specified with a comma, a range can be given with a hyphen, and the asterisk symbol is a wildcard character. Spaces are used to separate fields. For example, the line:

```
*/5 9-16 * 1-5,9-12 1-5 ~/bin/i_love_cron.sh

```

Will execute the script `i_love_cron.sh` at five minute intervals from 9 AM to 4:55 PM on weekdays except during the summer months (June, July, and August). More examples and advanced configuration techniques can be found below.

Besides, crontab has some special keywords:

```
@reboot at startup 
@yearly once a year
@annually ( == @yearly)
@monthly once a month
@weekly once a week
@daily once a day
@midnight ( == @daily)
@hourly once an hour

```

For example:

```
@reboot ~/bin/i_love_cron.sh

```

Will execute the script `i_love_cron.sh` at startup.

See more at: [http://www.linuxandlife.com/2013/01/how-to-use-crontab-to-schedule-tasks.html#sthash.AXvOdsAz.dpuf](http://www.linuxandlife.com/2013/01/how-to-use-crontab-to-schedule-tasks.html#sthash.AXvOdsAz.dpuf)

## Basic commands

Crontabs should never be edited directly; instead, users should use the `crontab` program to work with their crontabs. To be granted access to this command, user must be a member of the users group (see the `gpasswd` command).

To view their crontabs, users should issue the command:

```
$ crontab -l

```

To edit their crontabs, they may use:

```
$ crontab -e

```

**Note:** By default the `crontab` command uses the `vi` editor. To change it, [export](/index.php/Environment_variable "Environment variable") `EDITOR` or `VISUAL`, or specify the editor directly: `EDITOR=vim crontab -e`.

To remove their crontabs, they should use:

```
$ crontab -r

```

If a user has a saved crontab and would like to completely overwrite their old crontab, he or she should use:

```
$ crontab *saved_crontab_filename*

```

To overwrite a crontab from the command line ([Wikipedia:stdin](https://en.wikipedia.org/wiki/stdin "wikipedia:stdin")), use

```
$ crontab - 

```

To edit somebody else's crontab, issue the following command as root:

```
# crontab -u *username* -e

```

This same format (appending `-u *username*` to a command) works for listing and deleting crontabs as well.

## Examples

The entry:

```
01 * * * * /bin/echo Hello, world!

```

runs the command `/bin/echo Hello, world!` on the first minute of every hour of every day of every month (i.e. at 12:01, 1:01, 2:01, etc.).

Similarly:

```
*/5 * * jan mon-fri /bin/echo Hello, world!

```

runs the same job every five minutes on weekdays during the month of January (i.e. at 12:00, 12:05, 12:10, etc.).

The line (as noted in "man 5 crontab"):

```
*0,*5 9-16 * 1-5,9-12 1-5 /home/user/bin/i_love_cron.sh

```

will execute the script `i_love_cron.sh` at five minute intervals from 9 AM to 5 PM (excluding 5 PM itself) every weekday (Mon-Fri) of every month except during the summer (June, July, and August).

Periodical settings can also be entered as in this crontab template:

```
# Chronological table of program loadings                                       
# Edit with "crontab" for proper functionality, "man 5 crontab" for formatting
# User: johndoe

# mm  hh  DD  MM  W /path/progam [--option]...  ( W = weekday: 0-6 [Sun=0] )
  21  01  *   *   * /usr/bin/systemctl hibernate
  @weekly           $HOME/.local/bin/trash-empty

```

## Default editor

To use an alternate default editor, define the `EDITOR` environment variable in a shell initialization script as described in [Environment variables](/index.php/Environment_variables "Environment variables").

As a regular user, `su` will need to be used instead of `sudo` for the environment variable to be pulled correctly:

```
$ su -c "crontab -e"

```

To have an alias to this `printf` is required to carry the arbitrary string because `su` launches in a new shell:

```
alias scron="su -c $(printf "%q " "crontab -e")"

```

## run-parts issue

cronie uses `run-parts` to carry out script in `cron.daily`/`cron.weekly`/`cron.monthly`. Be careful that the script name in these won't include a dot (.), e.g. `backup.sh`, since `run-parts` without options will ignore them (see: `man run-parts`).

## Running X.org server-based applications

Cron does not run under the X.org server therefore it cannot know the environmental variable necessary to be able to start an X.org server application so they will have to be defined. One can use a program like [xuserrun](https://aur.archlinux.org/packages/xuserrun/) to do it:

```
17 02 * ... /usr/bin/xuserrun /usr/bin/xclock

```

Or then can be defined manually (`echo $DISPLAY` will give the current DISPLAY value):

```
17 02 * ... env DISPLAY=:0 /usr/bin/xclock

```

If done through say SSH, permission will need be given:

```
# xhost +si:localuser:$(whoami)

```

## Asynchronous job processing

If you regularly turn off your computer but do not want to miss jobs, there are some solutions available (easiest to hardest):

### Cronie

[cronie](https://www.archlinux.org/packages/?name=cronie) comes with anacron included. The project homepage reads:

Cronie contains the standard UNIX daemon crond that runs specified programs at scheduled times and related tools. It is based on the original cron and has security and configuration enhancements like the ability to use pam and SELinux.

### Dcron

Vanilla [dcron](https://aur.archlinux.org/packages/dcron/) supports asynchronous job processing. Just put it with @hourly, @daily, @weekly or @monthly with a jobname, like this:

```
@hourly         ID=greatest_ever_job      echo This job is very useful.

```

### Cronwhip

[cronwhip](https://aur.archlinux.org/packages/cronwhip/) is a script to automatically run missed cron jobs; it works with the former default cron implementation, *dcron*. See also the [forum thread](https://bbs.archlinux.org/viewtopic.php?id=57973).

### Anacron

Anacron is a full replacement for *dcron* which processes jobs asynchronously.

It is provided by [cronie](https://www.archlinux.org/packages/?name=cronie). The configuration file is `/etc/anacrontab`. Information on the format can be found in the `anacrontab(5)` [man page](/index.php/Man_page "Man page"). Running `anacron -T` will test `/etc/anacrontab` for validity.

### Fcron

Like *anacron*, [fcron](https://www.archlinux.org/packages/?name=fcron) assumes the computer is not always running and, unlike *anacron*, it can schedule events at intervals shorter than a single day which may be useful for systems which suspend/hibernate regularly (such as a laptop). Like cronwhip, fcron can run jobs that should have been run during the computer's downtime.

When replacing [cronie](https://www.archlinux.org/packages/?name=cronie) with fcron be aware the spool directory is `/var/spool/fcron` and the `fcrontab` command is used instead of *crontab* to edit the user crontabs. These crontabs are stored in a binary format with the text version next to them as *foo*.orig in the spool directory. Any scripts which manually edit user crontabs may need to be adjusted due to this difference in behavior.

A quick scriptlet which may aide in converting traditional user crontabs to fcron format:

```
cd /var/spool/cron && (
 for ctab in *; do
  fcrontab ${ctab} -u ${ctab}
 done
)

```

See also the [forum thread](https://bbs.archlinux.org/viewtopic.php?id=140497).

## Ensuring exclusivity

If you run potentially long-running jobs (e.g., a backup might all of a sudden run for a long time, because of many changes or a particular slow network connection), then `flock` ([util-linux](https://www.archlinux.org/packages/?name=util-linux)) can ensure that the cron job won't start a second time.

```
  5,35 * * * * /usr/bin/flock -n /tmp/lock.backup /root/make-backup.sh

```

## cronie

Long time users of vixie-cron (traditional cron) will be confused by how cronie is set up. Here is the relevant file hierarchy:

```
   /etc
     |----- anacrontab
     |----- cron.d
              | ----- 0hourly
     |----- cron.daily
     |----- cron.deny
     |----- cron.hourly
     |----- cron.monthly
     |----- cron.weekly
     |----- crontab

```

Note that the crontab file is **not** created by default, but jobs added here will be run if you wish to use this file. Cronie provides both cron and anacron functionality. The difference is that cron will run jobs at particular time intervals (down to a granularity of one minute) *if the machine is on at the particular time specified*, while anacron runs jobs (with a minimum daily granularity) without assuming that the machine is turned on all the time. When the machine is on, anacron will check to see if there are any jobs that *should have been run* and will run them accordingly. The `/etc/cron.d` and `/etc/cron.hourly` directories are associated with **cron** functionality, while the `/etc/anacrontab` file and `/etc/cron.daily`, `/etc/cron.weekly`, and `/etc/cron.monthly` directories are associated with **anacron** functionality. The `/etc/cron.deny` file is there so that any user who is not specifically prohibited can create their own cron jobs.

To implement a system-wide cron job, create a crontab-like file for it and place it in the `/etc/cron.d` directory or add the job to /etc/crontab. Any executable (these are almost always shell scripts) in `/etc/cron.hourly` will be run every hour.

Anacron functionality is implemented similarly, however using the `/etc/cron.daily`, `/etc/cron.weekly`, or `/etc/cron.monthly` directories, depending on how frequently you want the job to be run. The anacron job files are also executables; i.e. not in crontab-format. Anacron is triggered at the beginning of every hour by the crontab file `/etc/cron.d/0hourly` which runs the executables in `/etc/cron.hourly` including the file `/etc/cron.hourly/0anacron` - deleting these will prevent anacron running any daily, weekly or monthly tasks.

**Note:** the output of `systemctl status cronie` might show a message such as `crond[<PID>]: (root) CAN'T OPEN (/etc/crontab): No such file or directory`. However, this is not an error as of cronie 1.4.8\. See [this](https://lists.archlinux.org/pipermail/arch-general/2012-February/025178.html) discussion.

## Dcron

The cron daemon parses a configuration file known as `crontab`. Each user on the system can maintain a separate crontab file to schedule commands individually. The root user's crontab is used to schedule system-wide tasks (though users may opt to use `/etc/crontab` or the `/etc/cron.d` directory, depending on which cron implementation they choose).

```
/var/spool/cron/root

```

```
# Run command at a scheduled time
# Edit this 'crontab -e' for error checking, man 1 crontab for acceptable format

# <@freq>                       <tags and command>
@hourly         ID=sys-hourly   /usr/sbin/run-cron /etc/cron.hourly
@daily          ID=sys-daily    /usr/sbin/run-cron /etc/cron.daily
@weekly         ID=sys-weekly   /usr/sbin/run-cron /etc/cron.weekly
@monthly        ID=sys-monthly  /usr/sbin/run-cron /etc/cron.monthly

# mm  hh  DD  MM  W /path/command (or tags) # W = week: 0-6, Sun=0
  21  01  *   *   * /usr/bin/systemctl suspend

```

These lines exemplify one of the formats that crontab entries can have, namely whitespace-separated fields specifying:

1.  @period
2.  ID=jobname (this tag is specific to dcron)
3.  command

The other standard format for crontab entries is:

1.  minute
2.  hour
3.  day
4.  month
5.  day of week
6.  command

The crontab files themselves are usually stored as `/var/spool/cron/username`. For example, root's crontab is found at `/var/spool/cron/root`

See the crontab [man page](/index.php/Man_page "Man page") for further information and configuration examples.

## See also

*   [Gentoo Linux Cron Guide](http://www.gentoo.org/doc/en/cron-guide.xml)