In evolutionary biology, [cooperation](https://en.wikipedia.org/wiki/Co-operation_(evolution) describes interactions where an individual pays a small cost to yield a larger benefit to one or more others. If this costly contribution is reciprocated, everyone involved can benefit tremendously. This principle also applies to proactive members of the Arch community wanting to get involved and contribute to their favorite Linux distribution. Their participation benefits not only the community member and their fellow Archers, but all users of [free and open source software](https://en.wikipedia.org/wiki/Free_and_open_source_software "wikipedia:Free and open source software").

This article describes how both new and experienced Arch users can contribute to the community. Note that this is not an exhaustive list.

## Contents

*   [1 Official Arch Linux projects](#Official_Arch_Linux_projects)
    *   [1.1 Post on the forums](#Post_on_the_forums)
    *   [1.2 Improve this wiki](#Improve_this_wiki)
    *   [1.3 Join the chatroom](#Join_the_chatroom)
    *   [1.4 Report installed packages](#Report_installed_packages)
    *   [1.5 Fix and report bugs](#Fix_and_report_bugs)
    *   [1.6 Create and adopt AUR packages](#Create_and_adopt_AUR_packages)
    *   [1.7 Official software projects](#Official_software_projects)
    *   [1.8 Participate in events](#Participate_in_events)
    *   [1.9 Donate money](#Donate_money)
*   [2 Community projects](#Community_projects)
    *   [2.1 Groups](#Groups)
    *   [2.2 Software](#Software)
    *   [2.3 ArchWiki browsing](#ArchWiki_browsing)
    *   [2.4 Services](#Services)
    *   [2.5 Other](#Other)
*   [3 FAQ](#FAQ)
    *   [3.1 How can I become an Arch Developer?](#How_can_I_become_an_Arch_Developer.3F)
    *   [3.2 How can I become a Trusted User?](#How_can_I_become_a_Trusted_User.3F)
    *   [3.3 What can I do as an artist?](#What_can_I_do_as_an_artist.3F)

## Official Arch Linux projects

### Post on the forums

One of the easiest ways to get involved is participating in the [Arch Linux Forums](https://bbs.archlinux.org/), which allow getting to know the community and help new users.

Please get accustomed with [Forum etiquette](/index.php/Forum_etiquette "Forum etiquette"). Forum staff can be contacted via [forum@archlinux.org](mailto:forum@archlinux.org).

### Improve this wiki

[ArchWiki](/index.php/ArchWiki:About "ArchWiki:About") is a collaboratively maintained Arch Linux documentation. All users are encouraged to [contribute](/index.php/ArchWiki:Contributing "ArchWiki:Contributing").

### Join the chatroom

You can help other users to solve problems on the [IRC channel](/index.php/IRC_channel "IRC channel"). It is of vital importance however, that you read both the [rules](/index.php/IRC_channel#.23archlinux_rules "IRC channel") and [guidelines](/index.php/IRC_channel#.23archlinux_guidelines "IRC channel") before participating. [Further channels](/index.php/IRC_channels "IRC channels") are available for specific topics.

### Report installed packages

[pkgstats](/index.php/Pkgstats "Pkgstats") provides a systemd timer that sends a list of the packages installed on your system, along with the architecture and the mirrors you use, to the Arch Linux developers in order to help them prioritize their efforts and make the distribution even better. The information is sent anonymously and cannot be used to identify you. You can view the collected data at the [Statistics page](https://www.archlinux.de/?page=Statistics). More information is available in [this forum thread](https://bbs.archlinux.org/viewtopic.php?id=105431).

### Fix and report bugs

Reporting and fixing bugs on the [bug tracker](https://bugs.archlinux.org/) is one of the possible ways to help the community.

However, ineffective use can be counter-productive. Please read the [Reporting bug guidelines](/index.php/Reporting_bug_guidelines "Reporting bug guidelines").

### Create and adopt AUR packages

The [Arch User Repository](/index.php/Arch_User_Repository "Arch User Repository") contains community-made package scripts so that users can easily install software that is not in the official repositories. Popular packages get included into the [official community repository](/index.php/Official_repositories#community "Official repositories").

You can help by creating and adopting packages.

### Official software projects

You can get involved in the development of [official Arch Linux software projects](https://projects.archlinux.org/).

### Participate in events

There are yearly and monthly events for bugfixing, translating and cleanup. You can find forthcoming events in the [Arch Linux Event Calendar](/index.php/Arch_Linux_Event_Calendar "Arch Linux Event Calendar").

### Donate money

You can find out how to help sustaining server costs on the [official Arch Linux donate page](https://www.archlinux.org/donate/).

## Community projects

**Note:** All projects listed here are community projects. None of these projects are considered *official* Arch projects.

Arch's community maintains many projects. Feel free to include yours!

### Groups

Arch-specific groups that you can engage in.

	[ArchMap](/index.php/ArchMap "ArchMap")

	The ArchMap project creates a map of Arch Linux users all over the world.

	[ArchAudio](http://archaudio.org)

	A third-party package repository and online discussion board for Arch Linux pro-audio users.

	[Arch Linux Subreddit](http://www.reddit.com/r/archlinux/)

	Place for reddit users to discuss Arch related issues.

	[Arch Linux Google Plus Community](https://plus.google.com/communities/113935870359973712582)

	A Google Plus community for Arch Linux users to interact, post questions, or general Arch Linux news conversations.

	[Arch Linux User Group](/index.php/Arch_Linux_User_Group "Arch Linux User Group")

	Local meet-up for users.

	[Arch Women](http://archwomen.org/)

	Group with the intention of resolving possible hurdles for female Arch users ([forum thread](https://bbs.archlinux.org/viewtopic.php?id=136184)).

	[LinkedIn Group](http://www.linkedin.com/groups?gid=1399787)

	Arch Linux group for users and professionals.

### Software

Community-developed software that focuses on Arch Linux.

	[Arch User Repository](/index.php/Arch_User_Repository "Arch User Repository")

	A large community-driven repository for Arch users.

	[Unofficial user repositories](/index.php/Unofficial_user_repositories "Unofficial user repositories")

	Unofficial binary repositories maintained by community members.

	[AUR helpers](/index.php/AUR_helpers "AUR helpers")

	Utilities to aid end users in using the [Arch User Repository](/index.php/Arch_User_Repository "Arch User Repository").

	[Pacman GUI Frontends](/index.php/Pacman_GUI_Frontends "Pacman GUI Frontends")

	Graphical front-ends for [pacman](/index.php/Pacman "Pacman").

	[NetGUI](http://www.github.com/codywd/NetGUI)

	Graphical front end for [Netctl](/index.php/Netctl "Netctl").

### ArchWiki browsing

They offer you some different methods to visit ArchWiki.

	[arch-wiki-docs](https://github.com/lahwaacz/arch-wiki-docs)

	Pages from Arch Wiki optimized for offline browsing. Package: [arch-wiki-docs](https://www.archlinux.org/packages/?name=arch-wiki-docs).

	[arch-wiki-lite](http://kmkeen.com/arch-wiki-lite/)

	Arch-wiki-lite is designed to offer the smoothest possible experience for the poor person stuck without internet access or any way of starting a graphical web browser. Package: [arch-wiki-lite](https://www.archlinux.org/packages/?name=arch-wiki-lite).

	[ArchWiki Viewer for Android](https://bbs.archlinux.org/viewtopic.php?id=150538)

	A simple viewer for the ArchLinux Wiki online. Page content is formatted for optimal mobile viewing.

	[Wikicurses](https://bbs.archlinux.org/viewtopic.php?id=187864)

	A simple curses interface for MediaWiki sites such as ArchWiki or Wikipedia. Packages: [wikicurses](https://aur.archlinux.org/packages/wikicurses/), [wikicurses-git](https://aur.archlinux.org/packages/wikicurses-git/).

### Services

Services specifically made for Arch users.

	[ArchLinux.me](http://archlinux.me)

	Arch Linux Blogs, to register read [this forum post](https://bbs.archlinux.org/viewtopic.php?id=73622).

	[ArchLinux.info](https://bbs.archlinux.org/viewtopic.php?id=150417&)

	VPS-based @archlinux.info emails.

	[ProjectArch.tk](https://bbs.archlinux.org/viewtopic.php?id=206735&)

	Free ZNC accounts for Arch Linux users.

### Other

	[Xyne's Arch Linux Projects](http://xyne.archlinux.ca/projects/)

	A trusted user's arch-related projects.

## FAQ

### How can I become an Arch Developer?

The main motivation for your work on Arch should be helping the whole community, and not simply trying to become an *Arch developer* by any means.

Usually, new developers are picked by the existing developers as the workload increases. Sometimes they post a position and you can apply to fill it, but more often, they just invite somebody they know would be good at it and would fit in well with the rest of the team. Having a portfolio of Arch contributions is the best way to make it on the team.

Here is a list of things that you may do in order to gain some "popularity" towards Arch's developers:

*   Establish a reputation as being helpful by offering assistance whenever possible.
*   Answer questions on the forum, IRC, and mailing lists.
*   Join the [Trusted Users](/index.php/Trusted_Users "Trusted Users") to gain packaging experience to show your skills.
*   Submit packages to the AUR.
*   Join one of the offshoot projects that may be incorporated into Arch mainstream someday, or start your own.
*   Work on pacman, makepkg or other source code and submit patches to the bug tracker.
*   Traverse the bug tracker and fix existing bugs.
*   Find and submit new bugs.
*   Fix wiki errors, add new pages, clean up existing pages, and make sure the procedures are up-to-date.
*   Submit translations.

### How can I become a Trusted User?

Please read [Trusted Users#How to become TU?](/index.php/Trusted_Users#How_to_become_TU.3F "Trusted Users").

### What can I do as an artist?

Feel free to share wallpapers, splash screens, color palettes, widgets, themes, etc. with the community on the [art subforum](https://bbs.archlinux.org/viewforum.php?id=47).

See also [Arch Linux Art](https://www.archlinux.org/art/).