[Qt](http://qt-project.org/) is a cross-platform application and widget toolkit that uses standard C++ but makes extensive use of a special code generator (called the [Meta Object Compiler](http://qt-project.org/doc/qt-4.8/moc.html), or *moc*) together with several macros to enrich the language. Some of its more important features include:

*   Running on the major desktop platforms and some of the mobile platforms.
*   Extensive internationalization support.
*   A complete library that provides SQL database access, XML parsing, thread management, network support, and a unified cross-platform application programming interface (API) for file handling.

The Qt framework is emerging as a major development platform and is the basis of the [KDE](/index.php/KDE "KDE") software community, among other important open source and proprietary applications such as [VLC](/index.php/VLC "VLC"), [VirtualBox](/index.php/VirtualBox "VirtualBox"), [Mathematica](/index.php/Mathematica "Mathematica"), [Skype](/index.php/Skype "Skype") and many others.

## Contents

*   [1 Installation](#Installation)
    *   [1.1 Qt5 Platform Plugins and Missing Dependencies](#Qt5_Platform_Plugins_and_Missing_Dependencies)
*   [2 Default Qt toolkit](#Default_Qt_toolkit)
    *   [2.1 Using environment variables](#Using_environment_variables)
    *   [2.2 Using configuration files](#Using_configuration_files)
*   [3 Appearance](#Appearance)
    *   [3.1 Qt4](#Qt4)
    *   [3.2 Qt5](#Qt5)
    *   [3.3 Qt Style Sheets](#Qt_Style_Sheets)
    *   [3.4 GTK+ and Qt](#GTK.2B_and_Qt)
    *   [3.5 Configuration of Qt apps under environments other than KDE](#Configuration_of_Qt_apps_under_environments_other_than_KDE)
*   [4 Development](#Development)
    *   [4.1 Supported platforms](#Supported_platforms)
        *   [4.1.1 Android](#Android)
    *   [4.2 Tools](#Tools)
    *   [4.3 Bindings](#Bindings)
        *   [4.3.1 C++](#C.2B.2B)
        *   [4.3.2 QML](#QML)
        *   [4.3.3 Python (PyQt)](#Python_.28PyQt.29)
        *   [4.3.4 Python (PySide)](#Python_.28PySide.29)
        *   [4.3.5 C#](#C.23)
        *   [4.3.6 Ruby](#Ruby)
        *   [4.3.7 Java](#Java)
        *   [4.3.8 Perl](#Perl)
        *   [4.3.9 Lua](#Lua)
*   [5 Troubleshooting](#Troubleshooting)
    *   [5.1 Icon theme is not applied](#Icon_theme_is_not_applied)
    *   [5.2 Qt4 style not respected](#Qt4_style_not_respected)
*   [6 Resources](#Resources)

## Installation

Two versions of Qt are currently available in the [official repositories](/index.php/Official_repositories "Official repositories"). They can be [installed](/index.php/Pacman "Pacman") with the following packages:

*   **Qt 5.x** is available in the [qt5-base](https://www.archlinux.org/packages/?name=qt5-base) package, with documentation in the [qt5-doc](https://www.archlinux.org/packages/?name=qt5-doc) package.
*   **Qt 4.x** is available in the [qt4](https://www.archlinux.org/packages/?name=qt4) package, with documentation on AUR in the [qt4-doc](https://aur.archlinux.org/packages/qt4-doc/) package.
*   **Qt 3.x** is available from the AUR in the [qt3](https://aur.archlinux.org/packages/qt3/) package, with documentation on AUR in the [qt3-doc](https://aur.archlinux.org/packages/qt3-doc/) package.

**Warning:** Qt packages do not provide the usual bins (e.g. *qmake*) in `/usr/bin` anymore. Instead `-qt5`, `-qt4` and `-qt3` symlinks are provided (e.g. `qmake-qt5`, `qmake-qt4`, `qmake-qt3`). This may cause compilation failures in Qt3/4 applications. To install usual bins, see [#Default Qt toolkit](#Default_Qt_toolkit) section.

### Qt5 Platform Plugins and Missing Dependencies

Using [qt5-base](https://www.archlinux.org/packages/?name=qt5-base) will install Qt5, which makes use of [platform abstractions](http://doc.qt.io/qt-5/qpa.html), but some platform abstraction plugin dependencies may be missing. Qt may tell you that the plugin is unavailable, rather than resolve the chain of missing dependencies. For instance, if your application relies on [xcb](http://xcb.freedesktop.org), and dependencies of the xcb library are missing, Qt will report:

```
This application failed to start because it could not find or load the Qt platform plugin "xcb". Available plugins are: xcb.

Reinstalling the application may fix this problem.

```

The Qt5 page proposes a [list of packages](http://doc.qt.io/qt-5/linux-requirements.html) that are recommended for installation, blindly installing all of which may not be very Arch-like. Instead, you may identify the plugin (in the case of xcb, libqxcb.so), and use `ldd` to identify missing dependencies. Installing these dependencies should resolve the issue.

## Default Qt toolkit

By installing [qtchooser](https://www.archlinux.org/packages/?name=qtchooser) you can restore the usual bins (e.g. *qmake*) in `/usr/bin` and setup the Qt toolkit to use. By default Qt5 is used.

### Using environment variables

To define default Qt toolkit, you can create `QT_SELECT` [environment variable](/index.php/Environment_variable "Environment variable"). For example, to set Qt4, do `export QT_SELECT=4` in your shell's init file (e.g. `~/.bash_profile.` or `~/.zsh_profile.`).

### Using configuration files

You can set default Qt toolkit by creating a symlink `~/.config/qtchooser/default.conf` to one of *.conf* files in `/etc/xdg/qtchooser/` directory. For example, to set Qt4 symlink `/etc/xdg/qtchooser/4.conf` to `~/.config/qtchooser/default.conf`:

```
$ ln -s `/etc/xdg/qtchooser/4.conf` `~/.config/qtchooser/default.conf`

```

## Appearance

### Qt4

Qt4 application will try to mimic the behavior of the desktop environment they are running on, unless they run into some problems or hard-coded settings.

*   In KDE Plasma, it uses the actually selected Qt style. It can be configured using *KDE System Settings* (*systemsettings5*), the settings can be found in *Appearance > Application Style > Widget Style*.
*   In Cinnamon, GNOME, Xfce, it uses GTK+ ([QGtkStyle](/index.php/Uniform_look_for_Qt_and_GTK_applications#QGtkStyle "Uniform look for Qt and GTK applications")).
*   In other desktop environments, it uses Windows.

For those who want to change the look and feel of Qt4 application, the *Qt Configuration* (*qtconfig-qt4*) GUI tool is available. It offers a very simple configuration for the appearance of Qt4 applications that gives the user easy access to the current Qt Style, colors, fonts and other more advanced options.

**Note:** If you use *GTK+* style, then color and font settings will be ignored, and inherited from GTK+ 2.

Qt keeps all its configuration information in `/etc/xdg/Trolltech.conf` (system-wide) or `~/.config/Trolltech.conf` (user-specific). The file is rather difficult to navigate because it contains a lot of information not related to appearance, but for any changes you can just add to the end of the file and overwrite any previous values (make sure to add your modification under the [Qt] header).

For example, to change the theme to QtCurve, add:

 `~/.config/Trolltech.conf` 
```
...
[Qt]
style=QtCurve

```

The following styles are included in Qt4: *CDE*, *Cleanlooks*, *GTK+*, *Motif*, *Plastique*, *Windows*. Others can be installed from the official repositories or the [AUR](/index.php/AUR "AUR") (most are written for KDE Plasma Desktop):

*   **Breeze** — Artwork, styles and assets for the Breeze visual style for the Plasma Desktop.

	[https://projects.kde.org/projects/kde/workspace/breeze](https://projects.kde.org/projects/kde/workspace/breeze) || [breeze-kde4](https://www.archlinux.org/packages/?name=breeze-kde4)

*   **[Oxygen](https://en.wikipedia.org/wiki/Oxygen_Project "wikipedia:Oxygen Project")** — KDE Oxygen style.

	[https://projects.kde.org/projects/kde/workspace/oxygen](https://projects.kde.org/projects/kde/workspace/oxygen) || [oxygen-kde4](https://www.archlinux.org/packages/?name=oxygen-kde4)

*   **QtCurve** — A configurable set of widget styles for KDE and Gtk.

	[https://projects.kde.org/projects/playground/base/qtcurve](https://projects.kde.org/projects/playground/base/qtcurve) || [qtcurve-qt4](https://www.archlinux.org/packages/?name=qtcurve-qt4)

*   **Adwatia-Qt** — A style to bend Qt applications to look like they belong into GNOME Shell.

	[https://github.com/MartinBriza/adwaita-qt](https://github.com/MartinBriza/adwaita-qt) || [adwaita-qt4](https://aur.archlinux.org/packages/adwaita-qt4/)

### Qt5

Qt5 decides the style to use based on what desktop environment is used:

*   In KDE Plasma, it uses the actually selected Qt style. It can be configured using *KDE System Settings* (*systemsettings5*), the settings can be found in *Appearance > Application Style > Widget Style*.
*   In Cinnamon, GNOME, MATE, LXDE, Xfce, it uses GTK+ ([QGtkStyle](/index.php/Uniform_look_for_Qt_and_GTK_applications#QGtkStyle "Uniform look for Qt and GTK applications")).
*   In other desktop environments, it uses Fusion.

To force a specific style, you can set the `QT_STYLE_OVERRIDE` environment variable. Specifically, set it to `GTK+` if you want to use the gtk theme. Qt5 applications also support the `-style` flag, which you can use to launch a Qt5 application with a specific style.

The following styles are included in Qt5: *GTK+*, *Fusion*, *Windows*. Others can be installed from the official repositories:

*   **Breeze** — Artwork, styles and assets for the Breeze visual style for the Plasma Desktop.

	[https://projects.kde.org/projects/kde/workspace/breeze](https://projects.kde.org/projects/kde/workspace/breeze) || [breeze](https://www.archlinux.org/packages/?name=breeze)

*   **Oxygen** — KDE Oxygen style.

	[https://projects.kde.org/projects/kde/workspace/oxygen](https://projects.kde.org/projects/kde/workspace/oxygen) || [oxygen](https://www.archlinux.org/packages/?name=oxygen)

*   **QtCurve** — A configurable set of widget styles for KDE and Gtk.

	[https://projects.kde.org/projects/playground/base/qtcurve](https://projects.kde.org/projects/playground/base/qtcurve) || [qtcurve-qt5](https://www.archlinux.org/packages/?name=qtcurve-qt5)

*   **Adwatia-Qt** — A style to bend Qt applications to look like they belong into GNOME Shell.

	[https://github.com/MartinBriza/adwaita-qt](https://github.com/MartinBriza/adwaita-qt) || [adwaita-qt5](https://aur.archlinux.org/packages/adwaita-qt5/)

*   **Qt style plugins** — Additional style plugins for Qt5, including *Cleanlooks*, *Motif*, *Plastique*.

	[http://code.qt.io/cgit/qt/qtstyleplugins.git](http://code.qt.io/cgit/qt/qtstyleplugins.git) || [qt5-qtstyleplugins](https://aur.archlinux.org/packages/qt5-qtstyleplugins/)

### Qt Style Sheets

An interesting way of customizing the look and feel of a Qt application is using Style Sheets, which are just simple CSS files. Using Style Sheets, one can modify the appearance of every widget in the application.

To run an application with a different style just execute:

```
$ qt_application -stylesheet *style.qss*

```

For more information on Qt Style Sheets see the [official documentation](http://doc.qt.io/qt-5/stylesheet-reference.html) or other [tutorials](http://thesmithfam.org/blog/2009/09/10/qt-stylesheets-tutorial/). As an example Style Sheet see this [Dolphin modification](http://kde-apps.org/content/show.php/roxydoxy?content=125979).

### GTK+ and Qt

If you have GTK+ and Qt applications, their looks might not exactly blend in very well. If you wish to make your GTK+ styles match your Qt styles please read [Uniform look for Qt and GTK applications](/index.php/Uniform_look_for_Qt_and_GTK_applications "Uniform look for Qt and GTK applications").

### Configuration of Qt apps under environments other than KDE

Unlike Qt4, Qt5 doesn't ship a qtconfig utility to configure fonts, icons or styles. Instead, it will try to use the settings from the running DE. In KDE or GNOME this works well, but in other less popular DEs or WM it can lead to missing icons in Qt5 applications. One way to solve this is to fake the running desktop environment by setting `XDG_CURRENT_DESKTOP=KDE` or `GNOME`, and then using the corresponding configuration application to set the desired icon set.

Another solution is provided by the [qt5ct](https://www.archlinux.org/packages/?name=qt5ct) package, which provides a DE independent Qt5 QPA and a configuration utility. After installing the package, run `qt5ct` to set an icon theme, and set the environment variable `QT_QPA_PLATFORMTHEME="qt5ct"` so that the settings are picked up by Qt applications.

If the below errors are received, and some icons still do not appear in some of the apps, install [oxygen](https://www.archlinux.org/packages/?name=oxygen) and [oxygen-icons](https://www.archlinux.org/packages/?name=oxygen-icons):

```
Icon theme "oxygen" not found.
Icon theme "oxygen" not found.
Error: standard icon theme "oxygen" not found!

```

## Development

### Supported platforms

Qt supports most platforms that are available today, even some of the more obscure ones, with more ports appearing every once in a while. For a more complete list see the [Qt Wikipedia article](https://en.wikipedia.org/wiki/Qt_(framework)#Platforms "wikipedia:Qt (framework)").

#### Android

Use the [Qt for Android installer](http://download.qt.io/official_releases/qt/5.5/5.5.1/qt-opensource-linux-x64-android-5.5.1.run).

### Tools

The following are official Qt tools:

*   **[Qt Creator](https://en.wikipedia.org/wiki/Qt_Creator "wikipedia:Qt Creator")** — A cross-platform IDE tailored for Qt that supports all of its features.

	[http://qt-project.org/doc/qtcreator/](http://qt-project.org/doc/qtcreator/) || [qtcreator](https://www.archlinux.org/packages/?name=qtcreator)

*   **Qt Linguist** — A set of tools that speed the translation and internationalization of Qt applications.

	[http://qt-project.org/doc/qt-4.8/linguist-manual.html](http://qt-project.org/doc/qt-4.8/linguist-manual.html) || [qt4](https://www.archlinux.org/packages/?name=qt4)

*   **Qt Assistant** — A configurable and redistributable documentation reader for Qt *qch* files.

	[http://qt-project.org/doc/qt-4.8/assistant-manual.html](http://qt-project.org/doc/qt-4.8/assistant-manual.html) || [qt4](https://www.archlinux.org/packages/?name=qt4)

*   **Qt Designer** — A powerful cross-platform GUI layout and forms builder for Qt widgets.

	[http://qt-project.org/doc/qt-4.8/designer-manual.html](http://qt-project.org/doc/qt-4.8/designer-manual.html) || [qt4](https://www.archlinux.org/packages/?name=qt4)

*   **Qt Quick Designer** — A visual editor for QML files which supports WYSIWYG. It allows you to rapidly design and build Qt Quick applications and components from scratch.

	[http://qt-project.org/doc/qtcreator-2.8/creator-using-qt-quick-designer.html](http://qt-project.org/doc/qtcreator-2.8/creator-using-qt-quick-designer.html) || [qtcreator](https://www.archlinux.org/packages/?name=qtcreator)

*   **QML Viewer** — A tool for loading QML documents that makes it easy to quickly develop and debug QML applications.

	[http://qt-project.org/doc/qt-4.8/qmlviewer.html](http://qt-project.org/doc/qt-4.8/qmlviewer.html) || [qt4](https://www.archlinux.org/packages/?name=qt4)

*   **[qmake](https://en.wikipedia.org/wiki/Qmake "wikipedia:Qmake")** — A tool that helps simplify the build process for development project across different platforms, similar to [cmake](https://en.wikipedia.org/wiki/CMake "wikipedia:CMake"), but with fewer options and tailored for Qt applications.

	[https://qt-project.org/doc/qt-4.8/qmake-manual.html](https://qt-project.org/doc/qt-4.8/qmake-manual.html) || [qt4](https://www.archlinux.org/packages/?name=qt4)

*   **uic** — A tool that reads **.ui* XML files and generates the corresponding C++ files.

	[http://qt-project.org/doc/qt-4.8/uic.html](http://qt-project.org/doc/qt-4.8/uic.html) || [qt4](https://www.archlinux.org/packages/?name=qt4)

*   **rcc** — A tool that is used to embed resources (such as pictures) into a Qt application during the build process. It works by generating a C++ source file containing data specified in a Qt resource (.qrc) file.

	[http://qt-project.org/doc/qt-4.8/rcc.html](http://qt-project.org/doc/qt-4.8/rcc.html) || [qt4](https://www.archlinux.org/packages/?name=qt4)

*   **moc** — A tool that handles Qt's C++ extensions (the signals and slots mechanism, the run-time type information, and the dynamic property system, etc.).

	[http://doc.qt.digia.com/4.7-snapshot/moc.html](http://doc.qt.digia.com/4.7-snapshot/moc.html) || [qt4](https://www.archlinux.org/packages/?name=qt4)

### Bindings

Qt has bindings for all of the more popular languages, for a full list see [this list](https://en.wikipedia.org/wiki/Qt_(framework)#Programming_language_bindings "wikipedia:Qt (framework)").

The following examples display a small 'Hello world!' message in a window.

#### C++

*   Package:
    *   [qt4](https://www.archlinux.org/packages/?name=qt4) - Version 4.x of the Qt toolkit.
    *   [qt5-base](https://www.archlinux.org/packages/?name=qt5-base) - Version 5.x of the Qt toolkit.
*   Website: [http://qt-project.org/](http://qt-project.org/)
*   Build:
    *   The Qt4 version: `g++ $(pkg-config --cflags --libs QtGui) -o hello hello.cpp`
    *   The Qt5 version: `g++ $(pkg-config --cflags --libs Qt5Widgets) -o hello hello.cpp`
*   Run with: `./hello`

 `hello.cpp` 
```
#include <QApplication>
#include <QLabel>

int main(int argc, char **argv)
{
    QApplication app(argc, argv);
    QLabel hello("Hello world!");

    hello.show();
    return app.exec();
}

```

#### QML

*   Package: [qt4](https://www.archlinux.org/packages/?name=qt4) or [qt5-declarative](https://www.archlinux.org/packages/?name=qt5-declarative).
*   Website: [http://qt-project.org/](http://qt-project.org/)
*   Run with: `qmlviewer-qt4 hello.qml` or `qmlscene-qt5 hello.qml`

 `hello.qml` 
```
import QtQuick 1.0

Rectangle {
    id: page
    width: 400; height: 100
    color: "lightgray"

    Text {
        id: helloText
        text: "Hello world!"
        anchors.horizontalCenter: page.horizontalCenter
        anchors.verticalCenter: page.verticalCenter
        font.pointSize: 24; font.bold: true
    }
}

```

**Note:** For version 5.x of the Qt toolkit, we need to import QtQuick 2.y.

#### Python (PyQt)

*   Package:
    *   [python-pyqt4](https://www.archlinux.org/packages/?name=python-pyqt4) - Python 3.x bindings for Qt 4
    *   [python2-pyqt4](https://www.archlinux.org/packages/?name=python2-pyqt4) - Python 2.x bindings for Qt 4
    *   [python-pyqt5](https://www.archlinux.org/packages/?name=python-pyqt5) - Python 3.x bindings for Qt 5
    *   [python2-pyqt5](https://www.archlinux.org/packages/?name=python2-pyqt5) - Python 2.x bindings for Qt 5

*   Website: [http://www.riverbankcomputing.co.uk/software/pyqt/intro](http://www.riverbankcomputing.co.uk/software/pyqt/intro)
*   Run with: `python hello-pyqt.py` or `python2 hello-pyqt.py`.

 `hello-pyqt.py` 
```
import sys
from PyQt4 import QtGui

app = QtGui.QApplication(sys.argv)
label = QtGui.QLabel("Hello world!")

label.show()
sys.exit(app.exec_())

```

The Qt 5.x version is slighly different:

 `hello-pyqt.py` 
```
import sys
from PyQt5 import QtWidgets

app = QtWidgets.QApplication(sys.argv)
label = QtWidgets.QLabel("Hello world!")

label.show()
sys.exit(app.exec_())

```

#### Python (PySide)

*   Package:
    *   [python-pyside](https://www.archlinux.org/packages/?name=python-pyside) - Python 3.x bindings
    *   [python2-pyside](https://www.archlinux.org/packages/?name=python2-pyside) - Python 2.x bindings
*   Website: [http://www.pyside.org/](http://www.pyside.org/)
*   Run with: `python hello-pyside.py` or `python2 hello-pyside.py`

 `hello-pyside.py` 
```
import sys
from PySide.QtCore import *
from PySide.QtGui import *

app = QApplication(sys.argv)
label = QLabel("Hello world!")

label.show()
sys.exit(app.exec_())

```

#### C#

*   Package: [kdebindings-qyoto](https://aur.archlinux.org/packages/kdebindings-qyoto/)
*   Website: [http://techbase.kde.org/Development/Languages/Qyoto](http://techbase.kde.org/Development/Languages/Qyoto)
*   Build with: `mcs -pkg:qyoto hello.cs`
*   Run with: `mono hello.exe`

 `hello.cs` 
```
using System;
using Qyoto;

public class Hello {
    public static int Main(String[] args) {
        new QApplication(args);
        new QLabel("Hello world!").Show();

        return QApplication.Exec();
    }
}

```

#### Ruby

*   Package: [kdebindings-qtruby](https://aur.archlinux.org/packages/kdebindings-qtruby/)
*   Website: [http://rubyforge.org/projects/korundum/](http://rubyforge.org/projects/korundum/)
*   Run with: `ruby hello.rb`

 `hello.rb` 
```
require 'Qt4'

app = Qt::Application.new(ARGV)
hello = Qt::Label.new('Hello World!')

hello.show
app.exec

```

#### Java

*   Package: [qtjambi](https://aur.archlinux.org/packages/qtjambi/) or [qtjambi-beta](https://aur.archlinux.org/packages/qtjambi-beta/).
*   Website: [http://qt-jambi.org/](http://qt-jambi.org/)
*   Build with: `javac Hello.java -cp /opt/qtjambi-beta/qtjambi-linux64-community-4.7.0/qtjambi-4.7.0.jar`.
*   Run with: `java -cp /opt/qtjambi-beta/qtjambi-linux64-community-4.7.0/qtjambi-4.7.0.jar:. Hello`.

 `Hello.java` 
```
import com.trolltech.qt.gui.*;

public class Hello
{
    public static void main(String args[])
    {
        QApplication.initialize(args);
        QLabel hello = new QLabel("Hello World!");

        hello.show();
        QApplication.exec();
    }
}

```

**Note:** The build instructions and example have been tested on the beta version of Qt Jambi 4.7.0.

#### Perl

*   Package: [kdebindings-perlqt](https://aur.archlinux.org/packages/kdebindings-perlqt/)
*   Website: [http://code.google.com/p/perlqt4/](http://code.google.com/p/perlqt4/)
*   Run with: `perl hello.pl`

 `hello.pl` 
```
use QtGui4;

my $a = Qt::Application(\@ARGV);
my $hello = Qt::Label("Hello World!", undef);

$hello->show;
exit $a->exec;

```

#### Lua

*   Package: [libqtlua](https://aur.archlinux.org/packages/libqtlua/)
*   Website: [http://www.nongnu.org/libqtlua/](http://www.nongnu.org/libqtlua/)
*   Run with: `qtlua hello.lua`

 `hello.lua` 
```
label = qt.new_widget("QLabel")

label:setText("Hello World!")
label:show()

```

**Note:** QtLua is not designed to develop an application in pure Lua but rather to extend a Qt C++ application using Lua as scripting language.

## Troubleshooting

### Icon theme is not applied

Since Qt 5.1 SVG support has moved into a module. Since [qt5-base](https://www.archlinux.org/packages/?name=qt5-base) does not depend on [qt5-svg](https://www.archlinux.org/packages/?name=qt5-svg) it may happen that the [qt5-base](https://www.archlinux.org/packages/?name=qt5-base) is installed but not [qt5-svg](https://www.archlinux.org/packages/?name=qt5-svg). This results in deceptive icon theme behaviour. Since SVG is not supported the icons are silently skipped and the icon theme may seem to be unused. Installing [qt5-svg](https://www.archlinux.org/packages/?name=qt5-svg) explicitly solves the problem.

### Qt4 style not respected

If pure Qt4 (non-KDE) applications do not stick with your selected Qt4 style, then you'll probably need to tell Qt4 how to find KDE's styles (Oxygen, Phase etc.). You just need to set the environment variable QT_PLUGIN_PATH. E.g. put

```
export QT_PLUGIN_PATH=$HOME/.kde4/lib/kde4/plugins/:/usr/lib/kde4/plugins/

```

into your `/etc/profile` (or `~/.profile` if you do not have root access). `qtconfig-qt4` should then be able to find your kde styles and everything should look nice again!

Alternatively, you can symlink the Qt4 styles directory to the KDE4 styles one:

```
# ln -s /usr/lib/{kde,qt}4/plugins/styles/[theme name]

```

## Resources

*   [Official Website](http://qt.io/)
*   [Qt Documentation](http://doc.qt.io/)
*   [Planet Qt](http://planet.qt.io/)
*   [Qt Applications](http://qt-apps.org/)