**Warning:** SysVinit is not officially supported in Arch Linux [[1]](https://www.archlinux.org/news/end-of-initscripts-support/).

On systems based on SysVinit, **init** is the first process that is executed once the Linux kernel loads. The default init program used by the kernel is `/sbin/init` provided by [systemd-sysvcompat](https://www.archlinux.org/packages/?name=systemd-sysvcompat) (by default on new installs, see [systemd](/index.php/Systemd "Systemd")) or [sysvinit](https://aur.archlinux.org/packages/sysvinit/). The word **init** will always refer to sysvinit in this article.

**inittab** is the startup configuration file for init located in `/etc`. It contains directions for init on what programs and scripts to run when entering a specific runlevel.

Although a SysVinit-based Arch system does use init, most of the work is delegated to the [#Main Boot Scripts](#Main_Boot_Scripts). This article concentrates on init and inittab.

## Contents

*   [1 Installation](#Installation)
*   [2 Overview of init and inittab](#Overview_of_init_and_inittab)
*   [3 Switching runlevel](#Switching_runlevel)
    *   [3.1 Through bootloader](#Through_bootloader)
    *   [3.2 After boot up](#After_boot_up)
*   [4 inittab](#inittab)
    *   [4.1 Default Runlevel](#Default_Runlevel)
    *   [4.2 Main Boot Scripts](#Main_Boot_Scripts)
    *   [4.3 Single User Boot](#Single_User_Boot)
    *   [4.4 Gettys and Login](#Gettys_and_Login)
    *   [4.5 Ctrl+Alt+Del](#Ctrl.2BAlt.2BDel)
    *   [4.6 X Programs](#X_Programs)
    *   [4.7 Power-Sensing Scripts](#Power-Sensing_Scripts)
    *   [4.8 Custom Keyboard Request](#Custom_Keyboard_Request)
        *   [4.8.1 Trigger the kbrequest](#Trigger_the_kbrequest)
*   [5 Writing rc.d scripts](#Writing_rc.d_scripts)
    *   [5.1 Guideline](#Guideline)
    *   [5.2 Available functions](#Available_functions)
    *   [5.3 Example](#Example)
*   [6 Migration to systemd](#Migration_to_systemd)
    *   [6.1 Considerations before switching](#Considerations_before_switching)
    *   [6.2 Supplementary information](#Supplementary_information)
*   [7 See also](#See_also)

## Installation

Install [sysvinit](https://aur.archlinux.org/packages/sysvinit/) [initscripts-fork](https://aur.archlinux.org/packages/initscripts-fork/) from the [AUR](/index.php/AUR "AUR"). This step will remove [systemd-sysvcompat](https://www.archlinux.org/packages/?name=systemd-sysvcompat), and you will use sysvinit on reboot. To restore [systemd](/index.php/Systemd "Systemd"), append `init=/usr/lib/systemd/systemd` to the [kernel command line](/index.php/Kernel_command_line "Kernel command line").

Additional init scripts are available at [arch-rcscripts](https://bitbucket.org/TZ86/arch-rcscripts/src/3e83aeed6c68c6252b8db1428c10a717bc9e05ff/community/?at=master). See [Init#Configuration](/index.php/Init#Configuration "Init") for generic configuration steps.

## Overview of init and inittab

init is always process 1 and, other than managing some swap space, is the parent process to **all** other processes. You can get an idea of where init lies in the process hierarchy of your system with `pstree`:

 `$ pstree -Ap` 
```
init(1)-+-acpid(3432)
        |-crond(3423)
        |-dbus-daemon(3469)
        |-gpm(3485)
        |-mylogin(3536)
        |-ngetty(3535)---login(3954)---zsh(4043)---pstree(4326)
        |-polkitd(4033)---{polkitd}(4035)
        |-syslog-ng(3413)---syslog-ng(3414)
        `-udevd(643)-+-udevd(3194)
                     `-udevd(3218)

```

Besides usual initialization of system (as the name suggests), init also handles rebooting, shutdown and booting into recovery mode (single-user mode). To support these, inittab groups entries into different **runlevel**s. The runlevels Arch uses are 0 for halt, 1 (aliased as S) for single-user mode, 3 for normal booting (multi-user mode), 5 for X and 6 for reboot. Other distros may adopt other conventions, but the meanings of 0, 1 and 6 are universal.

Upon execution, init scans inittab and carry out appropriate actions. An entry in inittab takes the form

```
id:runlevels:action:process

```

Where `id` is a unique identifier for the entry (just a name, no real impact on init), and `runlevels` is a (not delimited) string of runlevels. If the runlevel init is entering appears in `runlevels`, `action` is carried out, executing `process` if appropriate. Some special `action`s would cause init to ignore `runlevels` and adopt a special matching method. More explanation follows in the next section.

See also `man 5 inittab` and `man 8 init`.

## Switching runlevel

### Through bootloader

To change the runlevel the system boots into, simply add the desired runlevel `n` to the respective bootloader's configuration line. A common application of this is [Start X at login#inittab](/index.php/Start_X_at_login#inittab "Start X at login"). To boot to the desired runlevel, add its number to the [kernel parameters](/index.php/Kernel_parameters "Kernel parameters") (e.g. `3` for runlevel 3).

The run-level was appended to the end so the kernel knows what run-level to start with. To use another init program (e.g. [systemd](/index.php/Systemd "Systemd")), add `init=/bin/systemd` or similar.

**Note:** If using some init other than sysvinit, the runlevel parameter might be ignored.

### After boot up

After the system has booted up, you may issue `telinit n` to inform init to change the runlevel to `n`. init then reads inittab and "diffs" runlevel n and current runlevel - killing processes not present in the new runlevel and carrying out actions not present in the old runlevel. Processes present in both runlevels are left untouched. The killing procedure is actually a little complex; again, technical details can be found in the init manpage.

init doesn't watch inittab. You need to call `telinit` explicitly to apply modifications to inittab. The command `telinit q` causes init to re-examine inittab but not switch runlevel.

## inittab

In this section we examine common entries in inittab, in the same order as they appear in the default inittab used by Arch. After that there are a few examples to help you create your own inittab entry.

**Warning:** Always test a modified `/etc/inittab` with `telinit q` before you reboot, or a small syntax error can prevent your system from booting.

### Default Runlevel

The default runlevel is 3\. Uncomment or add this if you prefer to boot into runlevel 5 (which is used for X conventionally) by default:

```
id:5:initdefault:

```

### Main Boot Scripts

These are the main Arch init scripts.

```
rc::sysinit:/etc/rc.sysinit
rs:S1:wait:/etc/rc.single
rm:2345:wait:/etc/rc.multi
rh:06:wait:/etc/rc.shutdown

```

### Single User Boot

Sometimes your kernel may fail to boot up all the way, due to a corrupted or dead hard drive or filesystem, missing key files, etc. In that case your init image may automatically enter into **single-user mode** which only allows root login and uses `/sbin/sulogin` instead of `/sbin/login` to control the login process. You can also boot into single-user mode by appending the letter `S` to your kernel command line in your [GRUB](/index.php/GRUB "GRUB"), [LILO](/index.php/LILO "LILO"), or [syslinux](/index.php/Syslinux "Syslinux") configuration. If you would like something other than sulogin to run, specify it here.

```
su:S:wait:/sbin/sulogin -p

```

### Gettys and Login

These are crucial entries that run the [gettys](/index.php/Getty "Getty") on your terminals. Most default configurations will have several gettys running on ttys1-6 which is what pops up on your screen with the login prompt. Also see openvt, chvt, stty, and ioctl.

```
c1:234:respawn:/sbin/agetty 9600 tty1 xterm-color
c5:5:respawn:/sbin/agetty 57600 tty2 xterm-256color

```

### Ctrl+Alt+Del

When the special key sequence `Ctrl+Alt+Del` is pressed, this determines what to do.

```
ca::ctrlaltdel:/sbin/shutdown -t3 -r now

```

### X Programs

If you are not afraid to debug, you can figure out how to start all sorts of programs from inittab. One useful type of program is to start your login manager when the runlevel is 5, multi-user-x-mode. In the following example you can see how to start [SLiM](/index.php/SLiM "SLiM") when entering runlevel 5.

```
x:5:respawn:/usr/bin/slim >/dev/null 2>&1
#x:5:respawn:/usr/bin/xdm -nodaemon -confi /etc/X11/xdm/archlinux/xdm-config

```

### Power-Sensing Scripts

Init can communicate with your UPS device and execute processes based on the status of the UPS. Here are some examples:

```
pf::powerfail:/sbin/shutdown -f -h +2 "Power Failure; System Shutting Down"
pr:12345:powerokwait:/sbin/shutdown -c "Power Restored; Shutdown Cancelled"

```

### Custom Keyboard Request

The following line adds a custom function for when a special key sequence is pressed. You can modify this special key sequence to be anything you like, similar to a `Ctrl+Alt+Del`.

```
kb::kbrequest:/usr/bin/wall "Keyboard Request -- edit /etc/inittab to customize"

```

#### Trigger the kbrequest

You can trigger the special key sequence **kbrequest** by sending the WINCH signal to the init process (1) as root (via sudo). In this example, the command:

```
kill -WINCH 1

```

Causes `wall` to write to all ttys:

```
Broadcast message from root@askapachehost (console) (Wed Oct 27 14:02:26 2010):
Keyboard Request -- edit /etc/inittab to customize

```

## Writing rc.d scripts

Initscripts uses rc.d scripts to used to control the starting, stopping and restarting of [daemons](/index.php/Daemons "Daemons").

### Guideline

*   Source `/etc/rc.conf`, `/etc/rc.d/functions`, and optionally `/etc/conf.d/DAEMON_NAME`.
*   Arguments and other daemon options should be placed in `/etc/conf.d/DAEMON_NAME`. This is done to separate configuration from logic and to keep a consistent style among daemon scripts.
*   Use functions in `/etc/rc.d/functions` instead of duplicating their functionality.
*   Include at least start, stop and restart as arguments to the script.

### Available functions

*   There are some functions provided by `/etc/rc.d/functions`:
    *   `stat_busy "*message*"`: set status *busy* for printed message (e.g. Starting daemon [BUSY])
    *   `stat_done`: set status *done* (e.g. Starting daemon [DONE])
    *   `stat_fail`: set status *failed* (e.g. Starting daemon [FAILED])
    *   `get_pid *program*`: get PID of the program
    *   `ck_pidfile *PID-file* *program*`: check whether PID-file is still valid for the program (e.g. ck_pidfile /var/run/daemon.pid daemon || rm -f /var/run/daemon.pid)
    *   `[add|rm]_daemon *program*`: add/remove program to running daemons (stored in `/run/daemons/`)

Full list of functions is much longer and most possibilities (like way to control whether or not non-root users can launch daemon) are still undocumented and can be learned only from `/etc/rc.d/functions` source. See also `man rc.d`.

### Example

The following is an example for *crond*. Look in `/etc/rc.d` for greater variety.

The configuration file:

 `/etc/conf.d/crond`  `ARGS="-S -l info"` 

The actual script:

 `/etc/rc.d/crond` 
```
#!/bin/bash

. /etc/rc.conf
. /etc/rc.d/functions

DAEMON=crond
ARGS=

[ -r /etc/conf.d/$DAEMON ] && . /etc/conf.d/$DAEMON

PID=$(get_pid $DAEMON)

case "$1" in
 start)
   stat_busy "Starting $DAEMON"
   [ -z "$PID" ] && $DAEMON $ARGS &>/dev/null
   if [ $? = 0 ]; then
     add_daemon $DAEMON
     stat_done
   else
     stat_fail
     exit 1
   fi
   ;;
 stop)
   stat_busy "Stopping $DAEMON"
   [ -n "$PID" ] && kill $PID &>/dev/null
   if [ $? = 0 ]; then
     rm_daemon $DAEMON
     stat_done
   else
     stat_fail
     exit 1
   fi
   ;;
 restart)
   $0 stop
   sleep 1
   $0 start
   ;;
 *)
   echo "usage: $0 {start|stop|restart}"  
esac

```

## Migration to systemd

**Note:**

*   [systemd](https://www.archlinux.org/packages/?name=systemd) and [systemd-sysvcompat](https://www.archlinux.org/packages/?name=systemd-sysvcompat) are both installed by default on installation media newer than [2012-10-13](https://www.archlinux.org/news/systemd-is-now-the-default-on-new-installations/). This section is aimed at Arch Linux installations that still rely on *sysvinit* and *initscripts*.
*   If you are running Arch Linux inside a VPS, please see [Virtual Private Server#Moving your VPS from initscripts to systemd](/index.php/Virtual_Private_Server#Moving_your_VPS_from_initscripts_to_systemd "Virtual Private Server").

### Considerations before switching

*   Interactive *initscripts* are not working with *systemd*. In particular, *netcfg-menu* cannot be used at system start-up ([FS#31377](https://bugs.archlinux.org/task/31377)).

### Supplementary information

*   It is not necessary to add your user to [groups](/index.php/Groups "Groups") (`sys`, `disk`, `lp`, `network`, `video`, `audio`, `optical`, `storage`, `scanner`, `power`, etc.) for most use cases with systemd. The groups can even cause some functionality to break. For example, the `audio` group will break fast user switching and allows applications to block software mixing. Every PAM login provides a logind session, which for a local session will give you permissions via [POSIX ACLs](https://en.wikipedia.org/wiki/Access_control_list "wikipedia:Access control list") on audio/video devices, and allow certain operations like mounting removable storage via [udisks](/index.php/Udisks "Udisks").

## See also

*   [Wikipedia: Init](https://en.wikipedia.org/wiki/Init "wikipedia:Init")
*   [Linux Knowledge Base and Tutorial. Run Levels.](http://www.linux-tutorial.info/modules.php?name=MContent&pageid=65)
*   [Linux.com. Introduction to runlevels and inittab](http://www.linux.com/articles/114107)
*   [Linux.com. An introduction to services, runlevels, and rc.d scripts.](http://www.linux.com/news/enterprise/systems-management/8116-an-introduction-to-services-runlevels-and-rcd-scripts)