[***Wolfenstein: Enemy Territory***](http://www.splashdamage.com/wolfet) (also known as ***Enemy Territory*** or just ***ET*** or ***W:ET***) is a free and open source multiplayer first-person shooter video game set during World War II which runs on Linux, Mac OS X and Windows. On the 12th August 2010, the entire source code was released under the GNU General Public License v3\. The open source project [***Enemy Territory: Legacy***](http://www.etlegacy.com/) is a collaborative effort focusing on fixing issues by backporting improvements from ioquake3 while staying binary compatible with the original game client, server and most of its mods.

## Contents

*   [1 Installation](#Installation)
    *   [1.1 Generate ETKey](#Generate_ETKey)
*   [2 Create CFG File (Optional)](#Create_CFG_File_.28Optional.29)
*   [3 Troubleshooting](#Troubleshooting)
    *   [3.1 No Sound](#No_Sound)
    *   [3.2 Wrong Resolution](#Wrong_Resolution)
    *   [3.3 Low FPS (Frames Per Second)](#Low_FPS_.28Frames_Per_Second.29)
    *   [3.4 PunkBuster](#PunkBuster)
    *   [3.5 hunk_alloc Errors](#hunk_alloc_Errors)

## Installation

Enemy Territory can be [installed](/index.php/AUR "AUR") from [enemy-territory](https://aur.archlinux.org/packages/enemy-territory/). Alternatively, the [official installer](http://www.splashdamage.com/content/download-wolfenstein-enemy-territory) can be downloaded from here: [http://filebase.trackbase.net/et/full/et260b.x86_full.zip](http://filebase.trackbase.net/et/full/et260b.x86_full.zip). Once installed you can run the game by executing this command:

```
$ et

```

Depending on your system, you might notice that ET is not emitting any music or sounds. If that is the case, please go to [#Troubleshooting](#Troubleshooting).

### Generate ETKey

Originally, PunkBuster client used to create a file known as `etkey` upon installation. This file is important as it is used to identify players, save player's XP and admin levels. Some servers do not allow players to play without ETKey. However, since EvenBalance ended it's PunkBuster support for Enemy Territory, the ETKey is not being generated anymore.

ETKey can be manually generated by following these steps:

1.  Go to [http://etkey.org/pages/etkey-home.php](http://etkey.org/pages/etkey-home.php) and download an ETKey from there.
2.  Copy the downloaded `etkey` file to `$HOME/.etwolf/etmain`
3.  Enable PunkBuster by running ET > Play Online > Enable PunkBuster (bottom right-hand side).

## Create CFG File (Optional)

Useful CVARs (i.e. ET commands) can be stored in a configuration (CFG) file. The following contains steps how to created such file:

1.  Create a plain text file in the following location: `$HOME/.etwolf/etmain/your_nickname.cfg`
2.  Open the file and add your desired commands. For example:

```
// Set your nickname (this line is a comment)
seta name         "^7Arch^dLinux"    // ^7 is the represents the white colour (i.e. text after ^7 will be displayed as white), while ^d represents blue

// Customize your HUD
seta cg_drawFPS   1    // displays your actual FPS (Frame Per Second) on your right hand side
seta cg_lagometer 1    // displays a connection-related display

// Others
seta com_maxfps   125  // 125 max FPS
seta com_hunkmegs 192  // in order to be able to load complex/graphic intensive maps

// ...etc...

```

To execute the CFG file:

1.  Open ET and connect to your favourite server.
2.  Open the **console** by pressing the `~` tilde key.
3.  Execute your CFG script by typing the following command: `\exec your_nickname.cfg`

## Troubleshooting

### No Sound

Enemy Territory was developed during a time when [OSS](/index.php/OSS "OSS") was still the 'official' Linux's sound system but was superseded by [ALSA](/index.php/ALSA "ALSA"). As a result, Enemy Territory might not be able to emit sound.

This problem can be solved by installing [et-sdl-sound](https://aur.archlinux.org/packages/et-sdl-sound/). If you are using an x86_64 architecture, you might need to [install](/index.php/Install "Install") the [gcc-multilib](https://www.archlinux.org/packages/?name=gcc-multilib) before installing [et-sdl-sound](https://aur.archlinux.org/packages/et-sdl-sound/). Once et-sdl-sound is installed, you can launch the game using the following command:

```
$ enemy-territory.sdl

```

### Wrong Resolution

You might not be able to find your official monitor's resolution in the Options page of ET. The problem can be solved by using a CFG file (see: [#Create CFG File (Optional)](#Create_CFG_File_.28Optional.29):

Open your CFG file and append the lines:

```
seta r_mode          -1      // -1 mean we are using a custom screen resolution
seta r_customwidth   1920    // monitor's width
seta r_customheight  1080    // monitor's height

```

Then execute the CFG file, open the console and type: `\vid_restart`.

### Low FPS (Frames Per Second)

On modern gaming rigs it was noted that Enemy Territory struggles to display playable FPS (especially if there are a lot of people playing in the server): sometimes the FPS may go below 30 while other times it may be around 125 FPS.

Follow these steps to solve the issue:

1.  Open your CFG file
2.  Append: `seta r_primitives 2`
3.  Execute your CFG file
4.  You might need to restart ET in order to see the desired results.

### PunkBuster

PunkBuster (PB for short) is no longer supporting Enemy Territory. As a result you may not be able to play on servers that still have PB enabled: symptoms of such behaviour might be automatic kicks after 1 or 2 minutes of play time.

This can be solved by manually updating your PB client to the latest version:

1.  Download the latest PB files from here: [http://etkey.org/pages/punkbuster/manual-installation.php](http://etkey.org/pages/punkbuster/manual-installation.php). This is not an official PB site, so use it at your own risk.
2.  Go to: `$HOME/.etwolf/`
3.  Create a directory named `pb` (if it does not exist).
4.  Extract to contents of the downloaded file into the directory mentioned above. The `pb` directory should contain at least 2 directories (`dll` and `htm`) plus a number of `so` files.
5.  Open your CFG file and add the following line:

    ```
    // Enables PunkBuster client   
    pb_cl_enable   
    seta cl_punkbuster 1   
    seta pb_system     1
    ```

6.  Run ET and execute your CFG file.
7.  Restart ET

### hunk_alloc Errors

Hunk_alloc errors are caused by maps that require more memory than how much Enemy Territory has allocated by default. Examples of such errors: `hunk_alloc failed at 12345` and/or `Hunk_AllocateTempMemory: failed on 12345`.

To fix it:

1.  Open your CFG file
2.  Append the following line: `seta com_hunkMegs 192    // sets the allowed memory for the graphics of the game` 
3.  Execute the CFG and restart ET.